# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/service/service_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from prodvana.proto.prodvana.capability import capability_pb2 as prodvana_dot_capability_dot_capability__pb2
from prodvana.proto.prodvana.common_config import constants_pb2 as prodvana_dot_common__config_dot_constants__pb2
from prodvana.proto.prodvana.common_config import env_pb2 as prodvana_dot_common__config_dot_env__pb2
from prodvana.proto.prodvana.common_config import kubernetes_config_pb2 as prodvana_dot_common__config_dot_kubernetes__config__pb2
from prodvana.proto.prodvana.common_config import helm_pb2 as prodvana_dot_common__config_dot_helm__pb2
from prodvana.proto.prodvana.common_config import maturity_pb2 as prodvana_dot_common__config_dot_maturity__pb2
from prodvana.proto.prodvana.common_config import parameters_pb2 as prodvana_dot_common__config_dot_parameters__pb2
from prodvana.proto.prodvana.common_config import program_pb2 as prodvana_dot_common__config_dot_program__pb2
from prodvana.proto.prodvana.common_config import retry_pb2 as prodvana_dot_common__config_dot_retry__pb2
from prodvana.proto.prodvana.common_config import rollback_pb2 as prodvana_dot_common__config_dot_rollback__pb2
from prodvana.proto.prodvana.common_config import task_pb2 as prodvana_dot_common__config_dot_task__pb2
from prodvana.proto.prodvana.delivery import delivery_config_pb2 as prodvana_dot_delivery_dot_delivery__config__pb2
from prodvana.proto.prodvana.delivery_extension import config_pb2 as prodvana_dot_delivery__extension_dot_config__pb2
from prodvana.proto.prodvana.desired_state.maestro import maestro_pb2 as prodvana_dot_desired__state_dot_maestro_dot_maestro__pb2
from prodvana.proto.prodvana.fly import fly_config_pb2 as prodvana_dot_fly_dot_fly__config__pb2
from prodvana.proto.prodvana.protection import attachments_pb2 as prodvana_dot_protection_dot_attachments__pb2
from prodvana.proto.prodvana.protection import protection_reference_pb2 as prodvana_dot_protection_dot_protection__reference__pb2
from prodvana.proto.prodvana.release_channel import release_channel_config_pb2 as prodvana_dot_release__channel_dot_release__channel__config__pb2
from prodvana.proto.prodvana.runtimes import runtimes_config_pb2 as prodvana_dot_runtimes_dot_runtimes__config__pb2
from prodvana.proto.prodvana.workflow import integration_config_pb2 as prodvana_dot_workflow_dot_integration__config__pb2
from prodvana.proto.prodvana.service import parameters_pb2 as prodvana_dot_service_dot_parameters__pb2
from prodvana.proto.prodvana.volumes import volumes_pb2 as prodvana_dot_volumes_dot_volumes__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%prodvana/service/service_config.proto\x12\x10prodvana.service\x1a\x1egoogle/protobuf/duration.proto\x1a$prodvana/capability/capability.proto\x1a&prodvana/common_config/constants.proto\x1a prodvana/common_config/env.proto\x1a.prodvana/common_config/kubernetes_config.proto\x1a!prodvana/common_config/helm.proto\x1a%prodvana/common_config/maturity.proto\x1a\'prodvana/common_config/parameters.proto\x1a$prodvana/common_config/program.proto\x1a\"prodvana/common_config/retry.proto\x1a%prodvana/common_config/rollback.proto\x1a!prodvana/common_config/task.proto\x1a\'prodvana/delivery/delivery_config.proto\x1a(prodvana/delivery_extension/config.proto\x1a,prodvana/desired_state/maestro/maestro.proto\x1a\x1dprodvana/fly/fly_config.proto\x1a%prodvana/protection/attachments.proto\x1a.prodvana/protection/protection_reference.proto\x1a\x35prodvana/release_channel/release_channel_config.proto\x1a\'prodvana/runtimes/runtimes_config.proto\x1a*prodvana/workflow/integration_config.proto\x1a!prodvana/service/parameters.proto\x1a\x1eprodvana/volumes/volumes.proto\x1a\x17validate/validate.proto\"1\n\x0eReplicasConfig\x12\x0f\n\x05\x66ixed\x18\x01 \x01(\x05H\x00\x42\x0e\n\x0c\x63onfig_oneof\"\xaa\x02\n\x0eMetricAnalysis\x12J\n\x0csuccess_rate\x18\x02 \x01(\x0b\x32\x32.prodvana.service.MetricAnalysis.SuccessRateConfigH\x00\x12\x45\n\x0blatency_p95\x18\x03 \x01(\x0b\x32..prodvana.service.MetricAnalysis.LatencyConfigH\x00\x1a\x32\n\x11SuccessRateConfig\x12\x1d\n\x15min_threshold_percent\x18\x01 \x01(\x01\x1a?\n\rLatencyConfig\x12.\n\x0bmax_latency\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x10\n\x0e\x61nalysis_oneof\"\xb7\x02\n\x15ReleaseStrategyConfig\x12<\n\x19individual_stage_deadline\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12=\n\x1a\x61utomated_testing_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12:\n\x10metrics_analysis\x18\x03 \x03(\x0b\x32 .prodvana.service.MetricAnalysis\x12\x17\n\x0fmanual_approval\x18\x04 \x01(\x08\x12\x31\n\x0e\x63heck_interval\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x19\n\x11\x66\x61ilure_threshold\x18\x06 \x01(\x05\"f\n\tTLSSecret\x12\x14\n\nraw_secret\x18\x03 \x01(\tH\x00\x12\x30\n\x06secret\x18\x04 \x01(\x0b\x32\x1e.prodvana.common_config.SecretH\x00\x42\x11\n\ntls_secret\x12\x03\xf8\x42\x01\"\x81\x01\n\x0eTLSCertificate\x12\x37\n\x08tls_cert\x18\x01 \x01(\x0b\x32\x1b.prodvana.service.TLSSecretB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x36\n\x07tls_key\x18\x02 \x01(\x0b\x32\x1b.prodvana.service.TLSSecretB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"j\n\x0b\x43\x65rtificate\x12/\n\x03tls\x18\x01 \x01(\x0b\x32 .prodvana.service.TLSCertificateH\x00\x12\x16\n\x0c\x61ws_acm_cert\x18\x02 \x01(\tH\x00\x42\x12\n\x0b\x63\x65rtificate\x12\x03\xf8\x42\x01\"\xf9\x0c\n\x17PerReleaseChannelConfig\x12 \n\x0frelease_channel\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12&\n\x10\x63ustom_hostnames\x18\x02 \x03(\tB\x0c\xfa\x42\t\x92\x01\x06\"\x04r\x02h\x01\x12W\n\x08programs\x18\x05 \x03(\x0b\x32\x36.prodvana.common_config.PerReleaseChannelProgramConfigB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x12+\n\x04\x63\x65rt\x18\x06 \x01(\x0b\x32\x1d.prodvana.service.Certificate\x12:\n\x0f\x64\x65livery_config\x18\x07 \x01(\x0b\x32!.prodvana.delivery.DeliveryConfig\x12\x38\n\x07volumes\x18\x08 \x03(\x0b\x32\x18.prodvana.volumes.VolumeB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x12\x32\n\x08replicas\x18\t \x01(\x0b\x32 .prodvana.service.ReplicasConfig\x12\x43\n\x0epre_push_tasks\x18\n \x03(\x0b\x32\x1c.prodvana.service.TaskConfigB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x12U\n\x13\x64\x65livery_extensions\x18\x12 \x03(\x0b\x32).prodvana.service.DeliveryExtensionConfigB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x12X\n\x16\x63onvergence_extensions\x18\x1a \x03(\x0b\x32).prodvana.service.DeliveryExtensionConfigB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x12\x41\n\x10runtime_specific\x18\x0b \x01(\x0b\x32\'.prodvana.service.RuntimeSpecificConfig\x12\x1a\n\x12runtime_connection\x18\x11 \x01(\t\x12\x45\n\x11runtime_extension\x18\r \x01(\x0b\x32(.prodvana.service.RuntimeExtensionConfigH\x00\x12\x42\n\x0e\x63ustom_runtime\x18\x19 \x01(\x0b\x32(.prodvana.service.RuntimeExtensionConfigH\x00\x12\x45\n\x11kubernetes_config\x18\x0e \x01(\x0b\x32(.prodvana.common_config.KubernetesConfigH\x00\x12\x43\n\x0f\x65xternal_config\x18\x10 \x01(\x0b\x32(.prodvana.common_config.KubernetesConfigH\x00\x12\x32\n\x04helm\x18\x0f \x01(\x0b\x32\".prodvana.common_config.HelmConfigH\x00\x12\x31\n\x07\x61ws_ecs\x18\x16 \x01(\x0b\x32\x1e.prodvana.service.AwsEcsConfigH\x00\x12\x42\n\x10google_cloud_run\x18\x18 \x01(\x0b\x32&.prodvana.service.GoogleCloudRunConfigH\x00\x12&\n\x03\x66ly\x18\x1b \x01(\x0b\x32\x17.prodvana.fly.FlyConfigH\x00\x12h\n\x03\x65nv\x18\x13 \x03(\x0b\x32\x32.prodvana.service.PerReleaseChannelConfig.EnvEntryB\'\xfa\x42$\x9a\x01!\x18\x01\"\x1dr\x1b\x32\x19^[a-zA-Z_]+[a-zA-Z0-9_]*$\x12\x33\n\tconstants\x18\x14 \x03(\x0b\x32 .prodvana.common_config.Constant\x12\x44\n\x0bprotections\x18\x15 \x03(\x0b\x32/.prodvana.protection.ProtectionAttachmentConfig\x12P\n\x17\x63onvergence_protections\x18\x17 \x03(\x0b\x32/.prodvana.protection.ProtectionAttachmentConfig\x1aL\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .prodvana.common_config.EnvValue:\x02\x38\x01\x42\x0e\n\x0c\x63onfig_oneofJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x0c\x10\r\",\n\x13\x43\x61pabilityReference\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"U\n\x18\x43ompiledCapabilityConfig\x12\x39\n\ncapability\x18\x01 \x01(\x0b\x32%.prodvana.capability.CapabilityConfig\".\n\x10ProgramReference\x12\x0e\n\x04name\x18\x01 \x01(\tH\x00\x42\n\n\x03ref\x12\x03\xf8\x42\x01\"6\n\rTaskReference\x12\x19\n\x0frelease_channel\x18\x01 \x01(\tH\x00\x42\n\n\x03ref\x12\x03\xf8\x42\x01\"\xf1\x01\n\nTaskConfig\x12@\n\x07program\x18\x01 \x01(\x0b\x32%.prodvana.common_config.ProgramConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x38\n\x0c\x62\x61se_program\x18\x02 \x01(\x0b\x32\".prodvana.service.ProgramReference\x12\x39\n\x0cretry_config\x18\x03 \x01(\x0b\x32#.prodvana.common_config.RetryConfig\x12,\n\x03ref\x18\x04 \x01(\x0b\x32\x1f.prodvana.service.TaskReference\"p\n\x0eProtectionLink\x12;\n\tlifecycle\x18\x03 \x01(\x0b\x32(.prodvana.protection.ProtectionLifecycle\x12\x15\n\rattachment_id\x18\x04 \x01(\tJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03\"\xa2\x02\n\x17\x44\x65liveryExtensionConfig\x12G\n\x07inlined\x18\x01 \x01(\x0b\x32\x34.prodvana.delivery_extension.DeliveryExtensionConfigH\x00\x12\x1b\n\x08instance\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12H\n\x03ref\x18\x04 \x01(\x0b\x32\x39.prodvana.delivery_extension.DeliveryExtensionInstanceRefH\x00\x12\x44\n\tlifecycle\x18\x02 \x01(\x0e\x32%.prodvana.common_config.TaskLifecycleB\n\xfa\x42\x07\x82\x01\x04 \x00 \x01\x42\x11\n\ndefinition\x12\x03\xf8\x42\x01\"\xe9\x01\n\x19\x44\x65liveryExtensionInstance\x12G\n\x07inlined\x18\x01 \x01(\x0b\x32\x34.prodvana.delivery_extension.DeliveryExtensionConfigH\x00\x12H\n\x03ref\x18\x03 \x01(\x0b\x32\x39.prodvana.delivery_extension.DeliveryExtensionInstanceRefH\x00\x12\x15\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x42\x11\n\ndefinition\x12\x03\xf8\x42\x01J\x04\x08\x04\x10\x05R\tlifecycle\"\x9c\x02\n\x15RuntimeSpecificConfig\x12@\n\x03k8s\x18\x01 \x01(\x0b\x32\x31.prodvana.service.RuntimeSpecificConfig.K8SConfigH\x00\x1a\xae\x01\n\tK8SConfig\x12\x66\n\x13service_annotations\x18\x01 \x03(\x0b\x32I.prodvana.service.RuntimeSpecificConfig.K8SConfig.ServiceAnnotationsEntry\x1a\x39\n\x17ServiceAnnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x10\n\x0eruntime_config\"\x86\x01\n\x16RuntimeExtensionConfig\x12@\n\x10parameter_values\x18\x01 \x03(\x0b\x32&.prodvana.common_config.ParameterValue\x12*\n\"clear_on_per_release_channel_merge\x18\x02 \x01(\x08\"\xac\x03\n\x0c\x41wsEcsConfig\x12!\n\x19\x65\x63s_service_name_override\x18\x01 \x01(\t\x12<\n\x0ftask_definition\x18\x02 \x01(\x0b\x32#.prodvana.service.AwsEcsConfig.Spec\x12?\n\x12service_definition\x18\x05 \x01(\x0b\x32#.prodvana.service.AwsEcsConfig.Spec\x12#\n\x1bupdate_task_definition_only\x18\x04 \x01(\x08\x1a\xb7\x01\n\x04Spec\x12\x1a\n\x07inlined\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12>\n\x05local\x18\x02 \x01(\x0b\x32#.prodvana.common_config.LocalConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x12@\n\x06remote\x18\x03 \x01(\x0b\x32$.prodvana.common_config.RemoteConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x42\x11\n\nspec_oneof\x12\x03\xf8\x42\x01J\x04\x08\x03\x10\x04R\x15network_configuration\"\xc7\x01\n\x14GoogleCloudRunConfig\x12\x1a\n\x07inlined\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12>\n\x05local\x18\x02 \x01(\x0b\x32#.prodvana.common_config.LocalConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x12@\n\x06remote\x18\x03 \x01(\x0b\x32$.prodvana.common_config.RemoteConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x42\x11\n\nspec_oneof\x12\x03\xf8\x42\x01\"\xa5\x14\n\rServiceConfig\x12\x39\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$\x12\x13\n\x0b\x61pplication\x18\x14 \x01(\t\x12\x46\n\x08programs\x18\x02 \x03(\x0b\x32%.prodvana.common_config.ProgramConfigB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x12\x32\n\x08replicas\x18\x04 \x01(\x0b\x32 .prodvana.service.ReplicasConfig\x12\x41\n\x10release_strategy\x18\x05 \x01(\x0b\x32\'.prodvana.service.ReleaseStrategyConfig\x12U\n\x13per_release_channel\x18\t \x03(\x0b\x32).prodvana.service.PerReleaseChannelConfigB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x12J\n\x0c\x63\x61pabilities\x18\n \x03(\x0b\x32%.prodvana.service.CapabilityReferenceB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x12:\n\x0f\x64\x65livery_config\x18\x0b \x01(\x0b\x32!.prodvana.delivery.DeliveryConfig\x12\x38\n\x07volumes\x18\x0c \x03(\x0b\x32\x18.prodvana.volumes.VolumeB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x12@\n\x12\x64\x65ploy_annotations\x18\r \x01(\x0b\x32$.prodvana.workflow.AnnotationsConfig\x12\x34\n\x0epre_push_tasks\x18\x0f \x03(\x0b\x32\x1c.prodvana.service.TaskConfig\x12\x46\n\x13\x64\x65livery_extensions\x18\x1d \x03(\x0b\x32).prodvana.service.DeliveryExtensionConfig\x12Q\n\x1c\x64\x65livery_extension_instances\x18\x1e \x03(\x0b\x32+.prodvana.service.DeliveryExtensionInstance\x12I\n\x16\x63onvergence_extensions\x18( \x03(\x0b\x32).prodvana.service.DeliveryExtensionConfig\x12T\n\x1f\x63onvergence_extension_instances\x18) \x03(\x0b\x32+.prodvana.service.DeliveryExtensionInstance\x12P\n\x17\x63onvergence_protections\x18% \x03(\x0b\x32/.prodvana.protection.ProtectionAttachmentConfig\x12\x41\n\x10runtime_specific\x18\x10 \x01(\x0b\x32\'.prodvana.service.RuntimeSpecificConfig\x12\x1a\n\x12runtime_connection\x18\x1c \x01(\t\x12N\n\nparameters\x18\x15 \x03(\x0b\x32+.prodvana.common_config.ParameterDefinitionB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x12\x42\n\x10parameter_values\x18\x16 \x01(\x0b\x32(.prodvana.service.ServiceParameterValues\x12\x33\n\tconstants\x18! \x03(\x0b\x32 .prodvana.common_config.Constant\x12\x34\n\x11progress_deadline\x18\x18 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x45\n\x11runtime_extension\x18\x12 \x01(\x0b\x32(.prodvana.service.RuntimeExtensionConfigH\x00\x12\x42\n\x0e\x63ustom_runtime\x18\' \x01(\x0b\x32(.prodvana.service.RuntimeExtensionConfigH\x00\x12\x45\n\x11kubernetes_config\x18\x13 \x01(\x0b\x32(.prodvana.common_config.KubernetesConfigH\x00\x12\x43\n\x0f\x65xternal_config\x18\x1b \x01(\x0b\x32(.prodvana.common_config.KubernetesConfigH\x00\x12\x32\n\x04helm\x18\x1a \x01(\x0b\x32\".prodvana.common_config.HelmConfigH\x00\x12\x31\n\x07\x61ws_ecs\x18# \x01(\x0b\x32\x1e.prodvana.service.AwsEcsConfigH\x00\x12\x42\n\x10google_cloud_run\x18$ \x01(\x0b\x32&.prodvana.service.GoogleCloudRunConfigH\x00\x12&\n\x03\x66ly\x18+ \x01(\x0b\x32\x17.prodvana.fly.FlyConfigH\x00\x12M\n\x12parameters_autogen\x18\x17 \x01(\x0e\x32\x31.prodvana.service.ServiceConfig.ParametersAutogen\x12\x41\n\rauto_rollback\x18\x19 \x01(\x0b\x32*.prodvana.common_config.AutoRollbackConfig\x12\x1c\n\x14no_cleanup_on_delete\x18\x1f \x01(\x08\x12^\n\x03\x65nv\x18  \x03(\x0b\x32(.prodvana.service.ServiceConfig.EnvEntryB\'\xfa\x42$\x9a\x01!\x18\x01\"\x1dr\x1b\x32\x19^[a-zA-Z_]+[a-zA-Z0-9_]*$\x12\x1f\n\x17\x61sync_set_desired_state\x18\" \x01(\x08\x12>\n\x07maestro\x18& \x01(\x0b\x32-.prodvana.desired_state.maestro.MaestroConfig\x12\x13\n\x0b\x62undle_name\x18* \x01(\t\x1aL\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .prodvana.common_config.EnvValue:\x02\x38\x01\"M\n\x11ParametersAutogen\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\t\n\x05IMAGE\x10\x02\x12\x16\n\x12IMAGE_AND_REPLICAS\x10\x03\x42\x0e\n\x0c\x63onfig_oneofJ\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08J\x04\x08\x08\x10\tJ\x04\x08\x0e\x10\x0fJ\x04\x08\x11\x10\x12R\x08\x65xternalR\x10image_repositoryR\rbase_templateR\x15\x63ontainer_registry_idR\x0bprotections\"\xd7\x10\n\x1d\x43ompiledServiceInstanceConfig\x12\x0f\n\x07service\x18\x01 \x01(\t\x12\x13\n\x0b\x61pplication\x18\x12 \x01(\t\x12\x17\n\x0frelease_channel\x18\x02 \x01(\t\x12\x37\n\x08programs\x18\x03 \x03(\x0b\x32%.prodvana.common_config.ProgramConfig\x12\x32\n\x08replicas\x18\x04 \x01(\x0b\x32 .prodvana.service.ReplicasConfig\x12\x32\n\x08maturity\x18\x05 \x01(\x0e\x32 .prodvana.common_config.Maturity\x12\x41\n\x10release_strategy\x18\x06 \x01(\x0b\x32\'.prodvana.service.ReleaseStrategyConfig\x12\x18\n\x10\x63ustom_hostnames\x18\x07 \x03(\t\x12+\n\x04\x63\x65rt\x18\n \x01(\x0b\x32\x1d.prodvana.service.Certificate\x12\x46\n\x07runtime\x18\x0b \x01(\x0b\x32\x35.prodvana.release_channel.ReleaseChannelRuntimeConfig\x12\x44\n\x11runtime_execution\x18\x1b \x01(\x0b\x32).prodvana.runtimes.RuntimeExecutionConfig\x12@\n\x0c\x63\x61pabilities\x18\x0c \x03(\x0b\x32*.prodvana.service.CompiledCapabilityConfig\x12:\n\x0f\x64\x65livery_config\x18\r \x01(\x0b\x32!.prodvana.delivery.DeliveryConfig\x12\x38\n\x07volumes\x18\x0e \x03(\x0b\x32\x18.prodvana.volumes.VolumeB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x12@\n\x12\x64\x65ploy_annotations\x18\x0f \x01(\x0b\x32$.prodvana.workflow.AnnotationsConfig\x12\x34\n\x0epre_push_tasks\x18\x11 \x03(\x0b\x32\x1c.prodvana.service.TaskConfig\x12I\n\x16\x63onvergence_extensions\x18\x1e \x03(\x0b\x32).prodvana.service.DeliveryExtensionConfig\x12T\n\x1f\x63onvergence_extension_instances\x18\x1f \x03(\x0b\x32+.prodvana.service.DeliveryExtensionInstance\x12\x41\n\x10runtime_specific\x18\x13 \x01(\x0b\x32\'.prodvana.service.RuntimeSpecificConfig\x12?\n\nparameters\x18\x18 \x03(\x0b\x32+.prodvana.common_config.ParameterDefinition\x12@\n\x10parameter_values\x18\x19 \x03(\x0b\x32&.prodvana.common_config.ParameterValue\x12\x33\n\tconstants\x18! \x03(\x0b\x32 .prodvana.common_config.Constant\x12\x34\n\x11progress_deadline\x18\x1a \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x42\n\x0e\x63ustom_runtime\x18\x16 \x01(\x0b\x32(.prodvana.service.RuntimeExtensionConfigH\x00\x12\x45\n\x11kubernetes_config\x18\x17 \x01(\x0b\x32(.prodvana.common_config.KubernetesConfigH\x00\x12\x32\n\x04helm\x18\x1d \x01(\x0b\x32\".prodvana.common_config.HelmConfigH\x00\x12\x31\n\x07\x61ws_ecs\x18% \x01(\x0b\x32\x1e.prodvana.service.AwsEcsConfigH\x00\x12\x42\n\x10google_cloud_run\x18\' \x01(\x0b\x32&.prodvana.service.GoogleCloudRunConfigH\x00\x12&\n\x03\x66ly\x18) \x01(\x0b\x32\x17.prodvana.fly.FlyConfigH\x00\x12n\n\x03\x65nv\x18\x1c \x03(\x0b\x32\x38.prodvana.service.CompiledServiceInstanceConfig.EnvEntryB\'\xfa\x42$\x9a\x01!\x18\x01\"\x1dr\x1b\x32\x19^[a-zA-Z_]+[a-zA-Z0-9_]*$\x12\x1c\n\x14no_cleanup_on_delete\x18  \x01(\x08\x12\x44\n\x0bprotections\x18\" \x03(\x0b\x32/.prodvana.protection.ProtectionAttachmentConfig\x12P\n\x17\x63onvergence_protections\x18& \x03(\x0b\x32/.prodvana.protection.ProtectionAttachmentConfig\x12\x13\n\x0b\x62undle_name\x18( \x01(\t\x1aL\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .prodvana.common_config.EnvValue:\x02\x38\x01\x42\x0e\n\x0c\x63onfig_oneofJ\x04\x08\x08\x10\tJ\x04\x08\t\x10\nJ\x04\x08\x10\x10\x11J\x04\x08\x14\x10\x15J\x04\x08\x15\x10\x16J\x04\x08#\x10$J\x04\x08$\x10%R\rbase_templateR\x0cruntime_type\"\x88\x02\n\x11\x43ompiledJobConfig\x12\x13\n\x0bname_prefix\x18\x01 \x01(\t\x12\x17\n\x0frelease_channel\x18\x02 \x01(\t\x12\x37\n\x08programs\x18\x03 \x03(\x0b\x32%.prodvana.common_config.ProgramConfig\x12\x46\n\x07runtime\x18\x04 \x01(\x0b\x32\x35.prodvana.release_channel.ReleaseChannelRuntimeConfig\x12\x44\n\x11runtime_execution\x18\x05 \x01(\x0b\x32).prodvana.runtimes.RuntimeExecutionConfigBLZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/serviceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.service.service_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/service'
  _TLSSECRET.oneofs_by_name['tls_secret']._options = None
  _TLSSECRET.oneofs_by_name['tls_secret']._serialized_options = b'\370B\001'
  _TLSCERTIFICATE.fields_by_name['tls_cert']._options = None
  _TLSCERTIFICATE.fields_by_name['tls_cert']._serialized_options = b'\372B\005\212\001\002\020\001'
  _TLSCERTIFICATE.fields_by_name['tls_key']._options = None
  _TLSCERTIFICATE.fields_by_name['tls_key']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CERTIFICATE.oneofs_by_name['certificate']._options = None
  _CERTIFICATE.oneofs_by_name['certificate']._serialized_options = b'\370B\001'
  _PERRELEASECHANNELCONFIG_ENVENTRY._options = None
  _PERRELEASECHANNELCONFIG_ENVENTRY._serialized_options = b'8\001'
  _PERRELEASECHANNELCONFIG.fields_by_name['release_channel']._options = None
  _PERRELEASECHANNELCONFIG.fields_by_name['release_channel']._serialized_options = b'\372B\004r\002\020\001'
  _PERRELEASECHANNELCONFIG.fields_by_name['custom_hostnames']._options = None
  _PERRELEASECHANNELCONFIG.fields_by_name['custom_hostnames']._serialized_options = b'\372B\t\222\001\006\"\004r\002h\001'
  _PERRELEASECHANNELCONFIG.fields_by_name['programs']._options = None
  _PERRELEASECHANNELCONFIG.fields_by_name['programs']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _PERRELEASECHANNELCONFIG.fields_by_name['volumes']._options = None
  _PERRELEASECHANNELCONFIG.fields_by_name['volumes']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _PERRELEASECHANNELCONFIG.fields_by_name['pre_push_tasks']._options = None
  _PERRELEASECHANNELCONFIG.fields_by_name['pre_push_tasks']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _PERRELEASECHANNELCONFIG.fields_by_name['delivery_extensions']._options = None
  _PERRELEASECHANNELCONFIG.fields_by_name['delivery_extensions']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _PERRELEASECHANNELCONFIG.fields_by_name['convergence_extensions']._options = None
  _PERRELEASECHANNELCONFIG.fields_by_name['convergence_extensions']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _PERRELEASECHANNELCONFIG.fields_by_name['env']._options = None
  _PERRELEASECHANNELCONFIG.fields_by_name['env']._serialized_options = b'\372B$\232\001!\030\001\"\035r\0332\031^[a-zA-Z_]+[a-zA-Z0-9_]*$'
  _CAPABILITYREFERENCE.fields_by_name['name']._options = None
  _CAPABILITYREFERENCE.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _PROGRAMREFERENCE.oneofs_by_name['ref']._options = None
  _PROGRAMREFERENCE.oneofs_by_name['ref']._serialized_options = b'\370B\001'
  _TASKREFERENCE.oneofs_by_name['ref']._options = None
  _TASKREFERENCE.oneofs_by_name['ref']._serialized_options = b'\370B\001'
  _TASKCONFIG.fields_by_name['program']._options = None
  _TASKCONFIG.fields_by_name['program']._serialized_options = b'\372B\005\212\001\002\020\001'
  _DELIVERYEXTENSIONCONFIG.oneofs_by_name['definition']._options = None
  _DELIVERYEXTENSIONCONFIG.oneofs_by_name['definition']._serialized_options = b'\370B\001'
  _DELIVERYEXTENSIONCONFIG.fields_by_name['instance']._options = None
  _DELIVERYEXTENSIONCONFIG.fields_by_name['instance']._serialized_options = b'\372B\004r\002\020\001'
  _DELIVERYEXTENSIONCONFIG.fields_by_name['lifecycle']._options = None
  _DELIVERYEXTENSIONCONFIG.fields_by_name['lifecycle']._serialized_options = b'\372B\007\202\001\004 \000 \001'
  _DELIVERYEXTENSIONINSTANCE.oneofs_by_name['definition']._options = None
  _DELIVERYEXTENSIONINSTANCE.oneofs_by_name['definition']._serialized_options = b'\370B\001'
  _DELIVERYEXTENSIONINSTANCE.fields_by_name['name']._options = None
  _DELIVERYEXTENSIONINSTANCE.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _RUNTIMESPECIFICCONFIG_K8SCONFIG_SERVICEANNOTATIONSENTRY._options = None
  _RUNTIMESPECIFICCONFIG_K8SCONFIG_SERVICEANNOTATIONSENTRY._serialized_options = b'8\001'
  _AWSECSCONFIG_SPEC.oneofs_by_name['spec_oneof']._options = None
  _AWSECSCONFIG_SPEC.oneofs_by_name['spec_oneof']._serialized_options = b'\370B\001'
  _AWSECSCONFIG_SPEC.fields_by_name['inlined']._options = None
  _AWSECSCONFIG_SPEC.fields_by_name['inlined']._serialized_options = b'\372B\004r\002\020\001'
  _AWSECSCONFIG_SPEC.fields_by_name['local']._options = None
  _AWSECSCONFIG_SPEC.fields_by_name['local']._serialized_options = b'\372B\005\212\001\002\020\001'
  _AWSECSCONFIG_SPEC.fields_by_name['remote']._options = None
  _AWSECSCONFIG_SPEC.fields_by_name['remote']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GOOGLECLOUDRUNCONFIG.oneofs_by_name['spec_oneof']._options = None
  _GOOGLECLOUDRUNCONFIG.oneofs_by_name['spec_oneof']._serialized_options = b'\370B\001'
  _GOOGLECLOUDRUNCONFIG.fields_by_name['inlined']._options = None
  _GOOGLECLOUDRUNCONFIG.fields_by_name['inlined']._serialized_options = b'\372B\004r\002\020\001'
  _GOOGLECLOUDRUNCONFIG.fields_by_name['local']._options = None
  _GOOGLECLOUDRUNCONFIG.fields_by_name['local']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GOOGLECLOUDRUNCONFIG.fields_by_name['remote']._options = None
  _GOOGLECLOUDRUNCONFIG.fields_by_name['remote']._serialized_options = b'\372B\005\212\001\002\020\001'
  _SERVICECONFIG_ENVENTRY._options = None
  _SERVICECONFIG_ENVENTRY._serialized_options = b'8\001'
  _SERVICECONFIG.fields_by_name['name']._options = None
  _SERVICECONFIG.fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$'
  _SERVICECONFIG.fields_by_name['programs']._options = None
  _SERVICECONFIG.fields_by_name['programs']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _SERVICECONFIG.fields_by_name['per_release_channel']._options = None
  _SERVICECONFIG.fields_by_name['per_release_channel']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _SERVICECONFIG.fields_by_name['capabilities']._options = None
  _SERVICECONFIG.fields_by_name['capabilities']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _SERVICECONFIG.fields_by_name['volumes']._options = None
  _SERVICECONFIG.fields_by_name['volumes']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _SERVICECONFIG.fields_by_name['parameters']._options = None
  _SERVICECONFIG.fields_by_name['parameters']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _SERVICECONFIG.fields_by_name['env']._options = None
  _SERVICECONFIG.fields_by_name['env']._serialized_options = b'\372B$\232\001!\030\001\"\035r\0332\031^[a-zA-Z_]+[a-zA-Z0-9_]*$'
  _COMPILEDSERVICEINSTANCECONFIG_ENVENTRY._options = None
  _COMPILEDSERVICEINSTANCECONFIG_ENVENTRY._serialized_options = b'8\001'
  _COMPILEDSERVICEINSTANCECONFIG.fields_by_name['volumes']._options = None
  _COMPILEDSERVICEINSTANCECONFIG.fields_by_name['volumes']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _COMPILEDSERVICEINSTANCECONFIG.fields_by_name['env']._options = None
  _COMPILEDSERVICEINSTANCECONFIG.fields_by_name['env']._serialized_options = b'\372B$\232\001!\030\001\"\035r\0332\031^[a-zA-Z_]+[a-zA-Z0-9_]*$'
  _globals['_REPLICASCONFIG']._serialized_start=993
  _globals['_REPLICASCONFIG']._serialized_end=1042
  _globals['_METRICANALYSIS']._serialized_start=1045
  _globals['_METRICANALYSIS']._serialized_end=1343
  _globals['_METRICANALYSIS_SUCCESSRATECONFIG']._serialized_start=1210
  _globals['_METRICANALYSIS_SUCCESSRATECONFIG']._serialized_end=1260
  _globals['_METRICANALYSIS_LATENCYCONFIG']._serialized_start=1262
  _globals['_METRICANALYSIS_LATENCYCONFIG']._serialized_end=1325
  _globals['_RELEASESTRATEGYCONFIG']._serialized_start=1346
  _globals['_RELEASESTRATEGYCONFIG']._serialized_end=1657
  _globals['_TLSSECRET']._serialized_start=1659
  _globals['_TLSSECRET']._serialized_end=1761
  _globals['_TLSCERTIFICATE']._serialized_start=1764
  _globals['_TLSCERTIFICATE']._serialized_end=1893
  _globals['_CERTIFICATE']._serialized_start=1895
  _globals['_CERTIFICATE']._serialized_end=2001
  _globals['_PERRELEASECHANNELCONFIG']._serialized_start=2004
  _globals['_PERRELEASECHANNELCONFIG']._serialized_end=3661
  _globals['_PERRELEASECHANNELCONFIG_ENVENTRY']._serialized_start=3551
  _globals['_PERRELEASECHANNELCONFIG_ENVENTRY']._serialized_end=3627
  _globals['_CAPABILITYREFERENCE']._serialized_start=3663
  _globals['_CAPABILITYREFERENCE']._serialized_end=3707
  _globals['_COMPILEDCAPABILITYCONFIG']._serialized_start=3709
  _globals['_COMPILEDCAPABILITYCONFIG']._serialized_end=3794
  _globals['_PROGRAMREFERENCE']._serialized_start=3796
  _globals['_PROGRAMREFERENCE']._serialized_end=3842
  _globals['_TASKREFERENCE']._serialized_start=3844
  _globals['_TASKREFERENCE']._serialized_end=3898
  _globals['_TASKCONFIG']._serialized_start=3901
  _globals['_TASKCONFIG']._serialized_end=4142
  _globals['_PROTECTIONLINK']._serialized_start=4144
  _globals['_PROTECTIONLINK']._serialized_end=4256
  _globals['_DELIVERYEXTENSIONCONFIG']._serialized_start=4259
  _globals['_DELIVERYEXTENSIONCONFIG']._serialized_end=4549
  _globals['_DELIVERYEXTENSIONINSTANCE']._serialized_start=4552
  _globals['_DELIVERYEXTENSIONINSTANCE']._serialized_end=4785
  _globals['_RUNTIMESPECIFICCONFIG']._serialized_start=4788
  _globals['_RUNTIMESPECIFICCONFIG']._serialized_end=5072
  _globals['_RUNTIMESPECIFICCONFIG_K8SCONFIG']._serialized_start=4880
  _globals['_RUNTIMESPECIFICCONFIG_K8SCONFIG']._serialized_end=5054
  _globals['_RUNTIMESPECIFICCONFIG_K8SCONFIG_SERVICEANNOTATIONSENTRY']._serialized_start=4997
  _globals['_RUNTIMESPECIFICCONFIG_K8SCONFIG_SERVICEANNOTATIONSENTRY']._serialized_end=5054
  _globals['_RUNTIMEEXTENSIONCONFIG']._serialized_start=5075
  _globals['_RUNTIMEEXTENSIONCONFIG']._serialized_end=5209
  _globals['_AWSECSCONFIG']._serialized_start=5212
  _globals['_AWSECSCONFIG']._serialized_end=5640
  _globals['_AWSECSCONFIG_SPEC']._serialized_start=5428
  _globals['_AWSECSCONFIG_SPEC']._serialized_end=5611
  _globals['_GOOGLECLOUDRUNCONFIG']._serialized_start=5643
  _globals['_GOOGLECLOUDRUNCONFIG']._serialized_end=5842
  _globals['_SERVICECONFIG']._serialized_start=5845
  _globals['_SERVICECONFIG']._serialized_end=8442
  _globals['_SERVICECONFIG_ENVENTRY']._serialized_start=3551
  _globals['_SERVICECONFIG_ENVENTRY']._serialized_end=3627
  _globals['_SERVICECONFIG_PARAMETERSAUTOGEN']._serialized_start=8240
  _globals['_SERVICECONFIG_PARAMETERSAUTOGEN']._serialized_end=8317
  _globals['_COMPILEDSERVICEINSTANCECONFIG']._serialized_start=8445
  _globals['_COMPILEDSERVICEINSTANCECONFIG']._serialized_end=10580
  _globals['_COMPILEDSERVICEINSTANCECONFIG_ENVENTRY']._serialized_start=3551
  _globals['_COMPILEDSERVICEINSTANCECONFIG_ENVENTRY']._serialized_end=3627
  _globals['_COMPILEDJOBCONFIG']._serialized_start=10583
  _globals['_COMPILEDJOBCONFIG']._serialized_end=10847
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import prodvana.proto.prodvana.protection.protection_manager_pb2

class ProtectionManagerStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    ConfigureProtection: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.protection.protection_manager_pb2.ConfigureProtectionReq,
        prodvana.proto.prodvana.protection.protection_manager_pb2.ConfigureProtectionResp,
    ]
    ValidateConfigureProtection: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.protection.protection_manager_pb2.ConfigureProtectionReq,
        prodvana.proto.prodvana.protection.protection_manager_pb2.ValidateConfigureProtectionResp,
    ]
    ListProtections: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.protection.protection_manager_pb2.ListProtectionsReq,
        prodvana.proto.prodvana.protection.protection_manager_pb2.ListProtectionsResp,
    ]
    GetProtection: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.protection.protection_manager_pb2.GetProtectionReq,
        prodvana.proto.prodvana.protection.protection_manager_pb2.GetProtectionResp,
    ]
    GetProtectionConfig: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.protection.protection_manager_pb2.GetProtectionConfigReq,
        prodvana.proto.prodvana.protection.protection_manager_pb2.GetProtectionConfigResp,
    ]
    GetProtectionAttachmentConfig: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.protection.protection_manager_pb2.GetProtectionAttachmentConfigReq,
        prodvana.proto.prodvana.protection.protection_manager_pb2.GetProtectionAttachmentConfigResp,
    ]

class ProtectionManagerServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def ConfigureProtection(
        self,
        request: prodvana.proto.prodvana.protection.protection_manager_pb2.ConfigureProtectionReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.protection.protection_manager_pb2.ConfigureProtectionResp: ...
    @abc.abstractmethod
    def ValidateConfigureProtection(
        self,
        request: prodvana.proto.prodvana.protection.protection_manager_pb2.ConfigureProtectionReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.protection.protection_manager_pb2.ValidateConfigureProtectionResp: ...
    @abc.abstractmethod
    def ListProtections(
        self,
        request: prodvana.proto.prodvana.protection.protection_manager_pb2.ListProtectionsReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.protection.protection_manager_pb2.ListProtectionsResp: ...
    @abc.abstractmethod
    def GetProtection(
        self,
        request: prodvana.proto.prodvana.protection.protection_manager_pb2.GetProtectionReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.protection.protection_manager_pb2.GetProtectionResp: ...
    @abc.abstractmethod
    def GetProtectionConfig(
        self,
        request: prodvana.proto.prodvana.protection.protection_manager_pb2.GetProtectionConfigReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.protection.protection_manager_pb2.GetProtectionConfigResp: ...
    @abc.abstractmethod
    def GetProtectionAttachmentConfig(
        self,
        request: prodvana.proto.prodvana.protection.protection_manager_pb2.GetProtectionAttachmentConfigReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.protection.protection_manager_pb2.GetProtectionAttachmentConfigResp: ...

def add_ProtectionManagerServicer_to_server(servicer: ProtectionManagerServicer, server: grpc.Server) -> None: ...



import os
from typing import Any, Callable, Optional, Sequence, Tuple

import grpc
from grpc_interceptor import ClientCallDetails, ClientInterceptor

from prodvana.proto.prodvana.application import application_manager_pb2_grpc
from prodvana.proto.prodvana.desired_state import manager_pb2_grpc
from prodvana.proto.prodvana.organization import organization_manager_pb2_grpc
from prodvana.proto.prodvana.release import manager_pb2_grpc as release_manager_pb2_grpc
from prodvana.proto.prodvana.release_channel import release_channel_manager_pb2_grpc
from prodvana.proto.prodvana.service import service_manager_pb2_grpc
from prodvana.proto.prodvana.workflow import workflow_manager_pb2_grpc


class AuthClientInterceptor(ClientInterceptor):
    def __init__(self, api_token: str) -> None:
        self.token = api_token
        self.header_value = f"Bearer {self.token}"

    def intercept(
        self,
        method: Callable[[Any, grpc.ClientCallDetails], Any],
        request_or_iterator: Any,
        call_details: grpc.ClientCallDetails,
    ) -> Any:
        metadata = []
        if call_details.metadata is not None:
            metadata = list(call_details.metadata)
        metadata.append(("authorization", self.header_value))
        new_details = ClientCallDetails(
            call_details.method,
            call_details.timeout,
            metadata,
            call_details.credentials,
            call_details.wait_for_ready,
            call_details.compression,
        )

        return method(request_or_iterator, new_details)


def make_channel(
    org: Optional[str] = None,
    apiserver_addr: Optional[str] = None,
    api_token: Optional[str] = None,
    options: Optional[Sequence[Tuple[str, Any]]] = None,
) -> grpc.Channel:
    """
    Make a new connection to Prodvana API.

    If `org` is provided, it is used to construct the api address automatically, i.e. api.<org>.prodvana.io.
    If `apiserver_addr` is provided, it is used. It must include both host name and port.
    Otherwise, env var PVN_APISERVER_ADDR is used.

    if `api_token` is not passed, env var PVN_TOKEN will be used.
    """
    if org is not None:
        apiserver_addr = f"api.{org}.prodvana.io:443"
    elif apiserver_addr is None:
        apiserver_addr = os.getenv("PVN_APISERVER_ADDR")
    assert (
        apiserver_addr
    ), "Must pass either `org`, `apiserver_addr`, or set env variable PVN_APISERVER_ADDR"
    if api_token is None:
        api_token = os.getenv("PVN_TOKEN")
    assert api_token, "Must pass either `api_token` or set env variabble PVN_TOKEN"
    server_name, _ = apiserver_addr.split(":")
    if server_name == "localhost" or server_name == "apiserver":  # for testing only
        channel = grpc.insecure_channel(apiserver_addr, options=options)
    else:
        channel = grpc.secure_channel(
            apiserver_addr, grpc.ssl_channel_credentials(), options=options
        )
    # use of an interceptor here instead of grpc.access_token_call_credentials is needed
    # because that function does not work with insecure_channel, see
    # https://groups.google.com/g/grpc-io/c/fFXbIXphudw
    channel = grpc.intercept_channel(channel, AuthClientInterceptor(api_token))
    return channel


class Client:
    def __init__(self, channel: grpc.Channel) -> None:
        self.application_manager = application_manager_pb2_grpc.ApplicationManagerStub(
            channel
        )
        self.organization_manager = (
            organization_manager_pb2_grpc.OrganizationManagerStub(channel)
        )
        self.release_channel_manager = (
            release_channel_manager_pb2_grpc.ReleaseChannelManagerStub(channel)
        )
        self.service_manager = service_manager_pb2_grpc.ServiceManagerStub(channel)
        self.desired_state_manager = manager_pb2_grpc.DesiredStateManagerStub(channel)
        self.workflow_manager = workflow_manager_pb2_grpc.WorkflowManagerStub(channel)
        self.release_manager = release_manager_pb2_grpc.ReleaseManagerStub(channel)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/desired_state/maestro/maestro.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2
from prodvana.proto.prodvana.desired_state.model import desired_state_pb2 as prodvana_dot_desired__state_dot_model_dot_desired__state__pb2
from prodvana.proto.prodvana.object import meta_pb2 as prodvana_dot_object_dot_meta__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,prodvana/desired_state/maestro/maestro.proto\x12\x1eprodvana.desired_state.maestro\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17validate/validate.proto\x1a\x30prodvana/desired_state/model/desired_state.proto\x1a\x1aprodvana/object/meta.proto\"U\n\rMaestroConfig\x12\x44\n\x08strategy\x18\x01 \x01(\x0e\x32(.prodvana.desired_state.maestro.StrategyB\x08\xfa\x42\x05\x82\x01\x02 \x00\"\xb4\x03\n\x14MaestroReleaseConfig\x12;\n\tentity_id\x18\x01 \x01(\x0b\x32(.prodvana.desired_state.model.Identifier\x12\x45\n\x0emaestro_config\x18\x02 \x01(\x0b\x32-.prodvana.desired_state.maestro.MaestroConfig\x12@\n\x13input_desired_state\x18\x05 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x43\n\x16\x63ompiled_desired_state\x18\x03 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x36\n\x12\x63reation_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12Y\n\x1aset_desired_state_metadata\x18\x06 \x01(\x0b\x32\x35.prodvana.desired_state.model.SetDesiredStateMetadata\"\xf0\x04\n\x13MaestroReleaseState\x12\x36\n\x06status\x18\x01 \x01(\x0e\x32&.prodvana.desired_state.maestro.Status\x12\x39\n\x15last_update_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12q\n\x18release_channel_statuses\x18\x03 \x03(\x0b\x32O.prodvana.desired_state.maestro.MaestroReleaseState.ReleaseChannelStatusesEntry\x12m\n\x16release_channel_states\x18\x04 \x03(\x0b\x32M.prodvana.desired_state.maestro.MaestroReleaseState.ReleaseChannelStatesEntry\x12$\n\x1cshared_root_desired_state_id\x18\x05 \x01(\t\x1a\x65\n\x1bReleaseChannelStatusesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x35\n\x05value\x18\x02 \x01(\x0e\x32&.prodvana.desired_state.maestro.Status:\x02\x38\x01\x1aw\n\x19ReleaseChannelStatesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12I\n\x05value\x18\x02 \x01(\x0b\x32:.prodvana.desired_state.maestro.MaestroReleaseChannelState:\x02\x38\x01\"\xa0\x01\n\x1aMaestroReleaseChannelState\x12\x36\n\x06status\x18\x01 \x01(\x0e\x32&.prodvana.desired_state.maestro.Status\x12\x18\n\x10\x64\x65sired_state_id\x18\x02 \x01(\t\x12\x11\n\tentity_id\x18\x03 \x01(\t\x12\x1d\n\x15root_desired_state_id\x18\x04 \x01(\t\"\xc5\x01\n\x0eMaestroRelease\x12)\n\x04meta\x18\x01 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\x12\x44\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x34.prodvana.desired_state.maestro.MaestroReleaseConfig\x12\x42\n\x05state\x18\x03 \x01(\x0b\x32\x33.prodvana.desired_state.maestro.MaestroReleaseState*b\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0f\n\x0bIN_PROGRESS\x10\x02\x12\r\n\tSUCCEEDED\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x12\x0b\n\x07SKIPPED\x10\x05*^\n\x08Strategy\x12\x14\n\x10UNKNOWN_STRATEGY\x10\x00\x12\x11\n\rRELEASE_TRAIN\x10\x02\x12\x14\n\x10MAESTRO_DISABLED\x10\x03\x12\r\n\tIMMEDIATE\x10\x04\"\x04\x08\x01\x10\x01\x42ZZXgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/desired_state/maestrob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.desired_state.maestro.maestro_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZXgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/desired_state/maestro'
  _MAESTROCONFIG.fields_by_name['strategy']._options = None
  _MAESTROCONFIG.fields_by_name['strategy']._serialized_options = b'\372B\005\202\001\002 \000'
  _MAESTRORELEASESTATE_RELEASECHANNELSTATUSESENTRY._options = None
  _MAESTRORELEASESTATE_RELEASECHANNELSTATUSESENTRY._serialized_options = b'8\001'
  _MAESTRORELEASESTATE_RELEASECHANNELSTATESENTRY._options = None
  _MAESTRORELEASESTATE_RELEASECHANNELSTATESENTRY._serialized_options = b'8\001'
  _globals['_STATUS']._serialized_start=1732
  _globals['_STATUS']._serialized_end=1830
  _globals['_STRATEGY']._serialized_start=1832
  _globals['_STRATEGY']._serialized_end=1926
  _globals['_MAESTROCONFIG']._serialized_start=216
  _globals['_MAESTROCONFIG']._serialized_end=301
  _globals['_MAESTRORELEASECONFIG']._serialized_start=304
  _globals['_MAESTRORELEASECONFIG']._serialized_end=740
  _globals['_MAESTRORELEASESTATE']._serialized_start=743
  _globals['_MAESTRORELEASESTATE']._serialized_end=1367
  _globals['_MAESTRORELEASESTATE_RELEASECHANNELSTATUSESENTRY']._serialized_start=1145
  _globals['_MAESTRORELEASESTATE_RELEASECHANNELSTATUSESENTRY']._serialized_end=1246
  _globals['_MAESTRORELEASESTATE_RELEASECHANNELSTATESENTRY']._serialized_start=1248
  _globals['_MAESTRORELEASESTATE_RELEASECHANNELSTATESENTRY']._serialized_end=1367
  _globals['_MAESTRORELEASECHANNELSTATE']._serialized_start=1370
  _globals['_MAESTRORELEASECHANNELSTATE']._serialized_end=1530
  _globals['_MAESTRORELEASE']._serialized_start=1533
  _globals['_MAESTRORELEASE']._serialized_end=1730
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import prodvana.proto.prodvana.object.meta_pb2
import prodvana.proto.prodvana.release_channel.release_channel_config_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ReleaseChannelProtectionAttachment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROTECTION_FIELD_NUMBER: builtins.int
    ATTACHMENT_FIELD_NUMBER: builtins.int
    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    ATTACHMENT_ID_FIELD_NUMBER: builtins.int
    protection: builtins.str
    attachment: builtins.str
    desired_state_id: builtins.str
    attachment_id: builtins.str
    def __init__(
        self,
        *,
        protection: builtins.str = ...,
        attachment: builtins.str = ...,
        desired_state_id: builtins.str = ...,
        attachment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["attachment", b"attachment", "attachment_id", b"attachment_id", "desired_state_id", b"desired_state_id", "protection", b"protection"]) -> None: ...

global___ReleaseChannelProtectionAttachment = ReleaseChannelProtectionAttachment

class ReleaseChannelState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROTECTION_ATTACHMENTS_FIELD_NUMBER: builtins.int
    @property
    def protection_attachments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReleaseChannelProtectionAttachment]: ...
    def __init__(
        self,
        *,
        protection_attachments: collections.abc.Iterable[global___ReleaseChannelProtectionAttachment] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["protection_attachments", b"protection_attachments"]) -> None: ...

global___ReleaseChannelState = ReleaseChannelState

class ReleaseChannel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    META_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    @property
    def meta(self) -> prodvana.proto.prodvana.object.meta_pb2.ObjectMeta: ...
    @property
    def config(self) -> prodvana.proto.prodvana.release_channel.release_channel_config_pb2.ReleaseChannelConfig: ...
    @property
    def state(self) -> global___ReleaseChannelState: ...
    def __init__(
        self,
        *,
        meta: prodvana.proto.prodvana.object.meta_pb2.ObjectMeta | None = ...,
        config: prodvana.proto.prodvana.release_channel.release_channel_config_pb2.ReleaseChannelConfig | None = ...,
        state: global___ReleaseChannelState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config", "meta", b"meta", "state", b"state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config", "meta", b"meta", "state", b"state"]) -> None: ...

global___ReleaseChannel = ReleaseChannel



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import prodvana.proto.prodvana.common_config.notification_pb2
import prodvana.proto.prodvana.common_config.program_pb2
import prodvana.proto.prodvana.common_config.retry_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class PushTask(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_ID_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_ID_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    ROLLBACK_FIELD_NUMBER: builtins.int
    APPLICATION_ID_FIELD_NUMBER: builtins.int
    APPLICATION_FIELD_NUMBER: builtins.int
    service_id: builtins.str
    """when passing as input, only specify one of service or service_id, not both"""
    service: builtins.str
    release_channel_id: builtins.str
    """when passing as input, only specify one of release_channel or release_channel_id, not both"""
    release_channel: builtins.str
    rollback: builtins.bool
    """deprecated, set at pipeline level instead of task level"""
    application_id: builtins.str
    application: builtins.str
    def __init__(
        self,
        *,
        service_id: builtins.str = ...,
        service: builtins.str = ...,
        release_channel_id: builtins.str = ...,
        release_channel: builtins.str = ...,
        rollback: builtins.bool = ...,
        application_id: builtins.str = ...,
        application: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "application_id", b"application_id", "release_channel", b"release_channel", "release_channel_id", b"release_channel_id", "rollback", b"rollback", "service", b"service", "service_id", b"service_id"]) -> None: ...

global___PushTask = PushTask

class WaitTask(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DURATION_FIELD_NUMBER: builtins.int
    @property
    def duration(self) -> google.protobuf.duration_pb2.Duration: ...
    def __init__(
        self,
        *,
        duration: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["duration", b"duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["duration", b"duration"]) -> None: ...

global___WaitTask = WaitTask

class ParallelTask(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class TaskTrack(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TASKS_FIELD_NUMBER: builtins.int
        @property
        def tasks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Task]: ...
        def __init__(
            self,
            *,
            tasks: collections.abc.Iterable[global___Task] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["tasks", b"tasks"]) -> None: ...

    TRACKS_FIELD_NUMBER: builtins.int
    @property
    def tracks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ParallelTask.TaskTrack]: ...
    def __init__(
        self,
        *,
        tracks: collections.abc.Iterable[global___ParallelTask.TaskTrack] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["tracks", b"tracks"]) -> None: ...

global___ParallelTask = ParallelTask

class ManualApprovalTask(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ManualApprovalTask = ManualApprovalTask

class CustomTask(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    PROGRAM_FIELD_NUMBER: builtins.int
    RETRY_CONFIG_FIELD_NUMBER: builtins.int
    APPLICATION_FIELD_NUMBER: builtins.int
    APPLICATION_ID_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_ID_FIELD_NUMBER: builtins.int
    FINAL_COMPILED_PROGRAM_FIELD_NUMBER: builtins.int
    description: builtins.str
    """description used for displaying this task"""
    @property
    def program(self) -> prodvana.proto.prodvana.common_config.program_pb2.ProgramConfig: ...
    @property
    def retry_config(self) -> prodvana.proto.prodvana.common_config.retry_pb2.RetryConfig:
        """if not set, the custom task will not be retried once it starts executing once."""
    application: builtins.str
    """TODO(naphat) is this the best interface, or do we just take runtime + namespace?"""
    application_id: builtins.str
    release_channel: builtins.str
    release_channel_id: builtins.str
    final_compiled_program: builtins.bool
    """if set, treat the program as the final program, avoid any internal Prodvana compilation (e.g. setting default env from app config)"""
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        program: prodvana.proto.prodvana.common_config.program_pb2.ProgramConfig | None = ...,
        retry_config: prodvana.proto.prodvana.common_config.retry_pb2.RetryConfig | None = ...,
        application: builtins.str = ...,
        application_id: builtins.str = ...,
        release_channel: builtins.str = ...,
        release_channel_id: builtins.str = ...,
        final_compiled_program: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["program", b"program", "retry_config", b"retry_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "application_id", b"application_id", "description", b"description", "final_compiled_program", b"final_compiled_program", "program", b"program", "release_channel", b"release_channel", "release_channel_id", b"release_channel_id", "retry_config", b"retry_config"]) -> None: ...

global___CustomTask = CustomTask

class Task(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Metadata(google.protobuf.message.Message):
        """Metadata contains information generic to all task types.
        Compilation of a task can be done entirely with its metadata and specific task-type config.
        """

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ID_FIELD_NUMBER: builtins.int
        id: builtins.int
        def __init__(
            self,
            *,
            id: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

    METADATA_FIELD_NUMBER: builtins.int
    PUSH_TASK_FIELD_NUMBER: builtins.int
    WAIT_TASK_FIELD_NUMBER: builtins.int
    PARALLEL_TASK_FIELD_NUMBER: builtins.int
    MANUAL_APPROVAL_TASK_FIELD_NUMBER: builtins.int
    CUSTOM_TASK_FIELD_NUMBER: builtins.int
    @property
    def metadata(self) -> global___Task.Metadata: ...
    @property
    def push_task(self) -> global___PushTask: ...
    @property
    def wait_task(self) -> global___WaitTask: ...
    @property
    def parallel_task(self) -> global___ParallelTask: ...
    @property
    def manual_approval_task(self) -> global___ManualApprovalTask: ...
    @property
    def custom_task(self) -> global___CustomTask: ...
    def __init__(
        self,
        *,
        metadata: global___Task.Metadata | None = ...,
        push_task: global___PushTask | None = ...,
        wait_task: global___WaitTask | None = ...,
        parallel_task: global___ParallelTask | None = ...,
        manual_approval_task: global___ManualApprovalTask | None = ...,
        custom_task: global___CustomTask | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["custom_task", b"custom_task", "manual_approval_task", b"manual_approval_task", "metadata", b"metadata", "parallel_task", b"parallel_task", "push_task", b"push_task", "task_oneof", b"task_oneof", "wait_task", b"wait_task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom_task", b"custom_task", "manual_approval_task", b"manual_approval_task", "metadata", b"metadata", "parallel_task", b"parallel_task", "push_task", b"push_task", "task_oneof", b"task_oneof", "wait_task", b"wait_task"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["task_oneof", b"task_oneof"]) -> typing_extensions.Literal["push_task", "wait_task", "parallel_task", "manual_approval_task", "custom_task"] | None: ...

global___Task = Task

class PipelineConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TASKS_FIELD_NUMBER: builtins.int
    ROLLBACK_FIELD_NUMBER: builtins.int
    NOTIFICATIONS_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def tasks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Task]: ...
    rollback: builtins.bool
    @property
    def notifications(self) -> prodvana.proto.prodvana.common_config.notification_pb2.NotificationConfig: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        tasks: collections.abc.Iterable[global___Task] | None = ...,
        rollback: builtins.bool = ...,
        notifications: prodvana.proto.prodvana.common_config.notification_pb2.NotificationConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["notifications", b"notifications"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "notifications", b"notifications", "rollback", b"rollback", "tasks", b"tasks"]) -> None: ...

global___PipelineConfig = PipelineConfig

class PipelineTemplate(google.protobuf.message.Message):
    """Similar to pipeline, but the task IDs and service fields are expected to not be filled out."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_SUFFIX_FIELD_NUMBER: builtins.int
    TASKS_FIELD_NUMBER: builtins.int
    ROLLBACK_FIELD_NUMBER: builtins.int
    NOTIFICATIONS_FIELD_NUMBER: builtins.int
    name_suffix: builtins.str
    @property
    def tasks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Task]: ...
    rollback: builtins.bool
    @property
    def notifications(self) -> prodvana.proto.prodvana.common_config.notification_pb2.NotificationConfig:
        """optional, will default to application's notification config"""
    def __init__(
        self,
        *,
        name_suffix: builtins.str = ...,
        tasks: collections.abc.Iterable[global___Task] | None = ...,
        rollback: builtins.bool = ...,
        notifications: prodvana.proto.prodvana.common_config.notification_pb2.NotificationConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["notifications", b"notifications"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name_suffix", b"name_suffix", "notifications", b"notifications", "rollback", b"rollback", "tasks", b"tasks"]) -> None: ...

global___PipelineTemplate = PipelineTemplate



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/common_config/kubernetes_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.prodvana/common_config/kubernetes_config.proto\x12\x16prodvana.common_config\x1a\x17validate/validate.proto\"\x97\x01\n\x0bLocalConfig\x12\x0e\n\x04path\x18\x01 \x01(\tH\x00\x12\r\n\x05paths\x18\x02 \x03(\t\x12\x10\n\x08sub_path\x18\x03 \x01(\t\x12\x18\n\x10\x65xclude_patterns\x18\x05 \x03(\t\x12\x18\n\x10include_patterns\x18\x06 \x03(\tB\x0c\n\npath_oneofJ\x04\x08\x04\x10\x05R\x0ftarball_blob_id\"K\n\x0cRemoteConfig\x12\x19\n\x0ftarball_blob_id\x18\x01 \x01(\tH\x00\x12\x10\n\x08sub_path\x18\x02 \x01(\tB\x0e\n\x0cremote_oneof\"\xb0\x04\n\x10KubernetesConfig\x12\x45\n\x04type\x18\x01 \x01(\x0e\x32-.prodvana.common_config.KubernetesConfig.TypeB\x08\xfa\x42\x05\x82\x01\x02 \x00\x12\x1a\n\x07inlined\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12\x34\n\x05local\x18\x03 \x01(\x0b\x32#.prodvana.common_config.LocalConfigH\x00\x12\x36\n\x06remote\x18\x05 \x01(\x0b\x32$.prodvana.common_config.RemoteConfigH\x00\x12U\n\x12\x65nv_injection_mode\x18\x04 \x01(\x0e\x32\x39.prodvana.common_config.KubernetesConfig.EnvInjectionMode\x12G\n\x07patches\x18\x06 \x03(\x0b\x32\'.prodvana.common_config.KubernetesPatchB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\"2\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0e\n\nKUBERNETES\x10\x01\x12\r\n\tKUSTOMIZE\x10\x02\"b\n\x10\x45nvInjectionMode\x12\x16\n\x12\x45NV_INJECT_UNKNOWN\x10\x00\x12\x17\n\x13\x45NV_INJECT_DISABLED\x10\x01\x12\x1d\n\x19\x45NV_INJECT_NON_SECRET_ENV\x10\x02\x42\x13\n\x0csource_oneof\x12\x03\xf8\x42\x01\"\xe4\x02\n\x0fKubernetesPatch\x12>\n\x06target\x18\x01 \x01(\x0b\x32..prodvana.common_config.KubernetesPatch.Target\x12L\n\x07replace\x18\x02 \x01(\x0b\x32/.prodvana.common_config.KubernetesPatch.ReplaceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x1aW\n\x06Target\x12\r\n\x05group\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x11\n\tnamespace\x18\x05 \x01(\t\x1aV\n\x07Replace\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x10\n\x06string\x18\x02 \x01(\tH\x00\x12\x17\n\rint_as_string\x18\x03 \x01(\tH\x00\x42\x12\n\x0bvalue_oneof\x12\x03\xf8\x42\x01\x42\x12\n\x0bpatch_oneof\x12\x03\xf8\x42\x01\x42RZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_configb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.common_config.kubernetes_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_config'
  _KUBERNETESCONFIG.oneofs_by_name['source_oneof']._options = None
  _KUBERNETESCONFIG.oneofs_by_name['source_oneof']._serialized_options = b'\370B\001'
  _KUBERNETESCONFIG.fields_by_name['type']._options = None
  _KUBERNETESCONFIG.fields_by_name['type']._serialized_options = b'\372B\005\202\001\002 \000'
  _KUBERNETESCONFIG.fields_by_name['inlined']._options = None
  _KUBERNETESCONFIG.fields_by_name['inlined']._serialized_options = b'\372B\004r\002\020\001'
  _KUBERNETESCONFIG.fields_by_name['patches']._options = None
  _KUBERNETESCONFIG.fields_by_name['patches']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _KUBERNETESPATCH_REPLACE.oneofs_by_name['value_oneof']._options = None
  _KUBERNETESPATCH_REPLACE.oneofs_by_name['value_oneof']._serialized_options = b'\370B\001'
  _KUBERNETESPATCH.oneofs_by_name['patch_oneof']._options = None
  _KUBERNETESPATCH.oneofs_by_name['patch_oneof']._serialized_options = b'\370B\001'
  _KUBERNETESPATCH.fields_by_name['replace']._options = None
  _KUBERNETESPATCH.fields_by_name['replace']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_LOCALCONFIG']._serialized_start=100
  _globals['_LOCALCONFIG']._serialized_end=251
  _globals['_REMOTECONFIG']._serialized_start=253
  _globals['_REMOTECONFIG']._serialized_end=328
  _globals['_KUBERNETESCONFIG']._serialized_start=331
  _globals['_KUBERNETESCONFIG']._serialized_end=891
  _globals['_KUBERNETESCONFIG_TYPE']._serialized_start=720
  _globals['_KUBERNETESCONFIG_TYPE']._serialized_end=770
  _globals['_KUBERNETESCONFIG_ENVINJECTIONMODE']._serialized_start=772
  _globals['_KUBERNETESCONFIG_ENVINJECTIONMODE']._serialized_end=870
  _globals['_KUBERNETESPATCH']._serialized_start=894
  _globals['_KUBERNETESPATCH']._serialized_end=1250
  _globals['_KUBERNETESPATCH_TARGET']._serialized_start=1055
  _globals['_KUBERNETESPATCH_TARGET']._serialized_end=1142
  _globals['_KUBERNETESPATCH_REPLACE']._serialized_start=1144
  _globals['_KUBERNETESPATCH_REPLACE']._serialized_end=1230
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class NotificationConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Slack(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CHANNEL_FIELD_NUMBER: builtins.int
        ERROR_CHANNEL_FIELD_NUMBER: builtins.int
        channel: builtins.str
        """catch all channel that will recieve all types of notifications"""
        error_channel: builtins.str
        """this channel will only recieve error/failure notifications"""
        def __init__(
            self,
            *,
            channel: builtins.str = ...,
            error_channel: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["channel", b"channel", "error_channel", b"error_channel"]) -> None: ...

    SLACK_FIELD_NUMBER: builtins.int
    @property
    def slack(self) -> global___NotificationConfig.Slack: ...
    def __init__(
        self,
        *,
        slack: global___NotificationConfig.Slack | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["slack", b"slack"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["slack", b"slack"]) -> None: ...

global___NotificationConfig = NotificationConfig



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import prodvana.proto.prodvana.object.manager_pb2

class ObjectManagerStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    QueryObjects: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.object.manager_pb2.QueryObjectReq,
        prodvana.proto.prodvana.object.manager_pb2.QueryObjectResp,
    ]
    GetLabels: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.object.manager_pb2.GetLabelsReq,
        prodvana.proto.prodvana.object.manager_pb2.GetLabelsResp,
    ]

class ObjectManagerServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def QueryObjects(
        self,
        request: prodvana.proto.prodvana.object.manager_pb2.QueryObjectReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.object.manager_pb2.QueryObjectResp: ...
    @abc.abstractmethod
    def GetLabels(
        self,
        request: prodvana.proto.prodvana.object.manager_pb2.GetLabelsReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.object.manager_pb2.GetLabelsResp: ...

def add_ObjectManagerServicer_to_server(servicer: ObjectManagerServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ExternalLink(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _LinkType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _LinkTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ExternalLink._LinkType.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: ExternalLink._LinkType.ValueType  # 0
        DETAIL: ExternalLink._LinkType.ValueType  # 1
        LOG: ExternalLink._LinkType.ValueType  # 2

    class LinkType(_LinkType, metaclass=_LinkTypeEnumTypeWrapper): ...
    UNKNOWN: ExternalLink.LinkType.ValueType  # 0
    DETAIL: ExternalLink.LinkType.ValueType  # 1
    LOG: ExternalLink.LinkType.ValueType  # 2

    TYPE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    type: global___ExternalLink.LinkType.ValueType
    url: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        type: global___ExternalLink.LinkType.ValueType = ...,
        url: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "type", b"type", "url", b"url"]) -> None: ...

global___ExternalLink = ExternalLink



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from prodvana.proto.prodvana.deployment import manager_pb2 as prodvana_dot_deployment_dot_manager__pb2


class DeploymentManagerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RecordDeployment = channel.unary_unary(
                '/prodvana.deployment.DeploymentManager/RecordDeployment',
                request_serializer=prodvana_dot_deployment_dot_manager__pb2.RecordDeploymentReq.SerializeToString,
                response_deserializer=prodvana_dot_deployment_dot_manager__pb2.RecordDeploymentResp.FromString,
                )
        self.UpdateDeploymentStatus = channel.unary_unary(
                '/prodvana.deployment.DeploymentManager/UpdateDeploymentStatus',
                request_serializer=prodvana_dot_deployment_dot_manager__pb2.UpdateDeploymentStatusReq.SerializeToString,
                response_deserializer=prodvana_dot_deployment_dot_manager__pb2.UpdateDeploymentStatusResp.FromString,
                )
        self.ListDeployments = channel.unary_unary(
                '/prodvana.deployment.DeploymentManager/ListDeployments',
                request_serializer=prodvana_dot_deployment_dot_manager__pb2.ListDeploymentsReq.SerializeToString,
                response_deserializer=prodvana_dot_deployment_dot_manager__pb2.ListDeploymentsResp.FromString,
                )
        self.ListDeploymentsStream = channel.unary_stream(
                '/prodvana.deployment.DeploymentManager/ListDeploymentsStream',
                request_serializer=prodvana_dot_deployment_dot_manager__pb2.ListDeploymentsReq.SerializeToString,
                response_deserializer=prodvana_dot_deployment_dot_manager__pb2.ListDeploymentsResp.FromString,
                )
        self.CompareDeployment = channel.unary_unary(
                '/prodvana.deployment.DeploymentManager/CompareDeployment',
                request_serializer=prodvana_dot_deployment_dot_manager__pb2.CompareDeploymentReq.SerializeToString,
                response_deserializer=prodvana_dot_deployment_dot_manager__pb2.CompareDeploymentResp.FromString,
                )
        self.PreviewDeployment = channel.unary_unary(
                '/prodvana.deployment.DeploymentManager/PreviewDeployment',
                request_serializer=prodvana_dot_deployment_dot_manager__pb2.PreviewDeploymentReq.SerializeToString,
                response_deserializer=prodvana_dot_deployment_dot_manager__pb2.PreviewDeploymentResp.FromString,
                )
        self.GetLatestDeployments = channel.unary_unary(
                '/prodvana.deployment.DeploymentManager/GetLatestDeployments',
                request_serializer=prodvana_dot_deployment_dot_manager__pb2.GetLatestDeploymentsReq.SerializeToString,
                response_deserializer=prodvana_dot_deployment_dot_manager__pb2.GetLatestDeploymentsResp.FromString,
                )
        self.CheckCommitInDeployment = channel.unary_unary(
                '/prodvana.deployment.DeploymentManager/CheckCommitInDeployment',
                request_serializer=prodvana_dot_deployment_dot_manager__pb2.CheckCommitInDeploymentReq.SerializeToString,
                response_deserializer=prodvana_dot_deployment_dot_manager__pb2.CheckCommitInDeploymentResp.FromString,
                )


class DeploymentManagerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def RecordDeployment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDeploymentStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDeployments(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDeploymentsStream(self, request, context):
        """page tokens arguments are ignored here
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CompareDeployment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PreviewDeployment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLatestDeployments(self, request, context):
        """returns the latest deployments for each (application, service, deployment channel) tuple.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckCommitInDeployment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DeploymentManagerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'RecordDeployment': grpc.unary_unary_rpc_method_handler(
                    servicer.RecordDeployment,
                    request_deserializer=prodvana_dot_deployment_dot_manager__pb2.RecordDeploymentReq.FromString,
                    response_serializer=prodvana_dot_deployment_dot_manager__pb2.RecordDeploymentResp.SerializeToString,
            ),
            'UpdateDeploymentStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDeploymentStatus,
                    request_deserializer=prodvana_dot_deployment_dot_manager__pb2.UpdateDeploymentStatusReq.FromString,
                    response_serializer=prodvana_dot_deployment_dot_manager__pb2.UpdateDeploymentStatusResp.SerializeToString,
            ),
            'ListDeployments': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDeployments,
                    request_deserializer=prodvana_dot_deployment_dot_manager__pb2.ListDeploymentsReq.FromString,
                    response_serializer=prodvana_dot_deployment_dot_manager__pb2.ListDeploymentsResp.SerializeToString,
            ),
            'ListDeploymentsStream': grpc.unary_stream_rpc_method_handler(
                    servicer.ListDeploymentsStream,
                    request_deserializer=prodvana_dot_deployment_dot_manager__pb2.ListDeploymentsReq.FromString,
                    response_serializer=prodvana_dot_deployment_dot_manager__pb2.ListDeploymentsResp.SerializeToString,
            ),
            'CompareDeployment': grpc.unary_unary_rpc_method_handler(
                    servicer.CompareDeployment,
                    request_deserializer=prodvana_dot_deployment_dot_manager__pb2.CompareDeploymentReq.FromString,
                    response_serializer=prodvana_dot_deployment_dot_manager__pb2.CompareDeploymentResp.SerializeToString,
            ),
            'PreviewDeployment': grpc.unary_unary_rpc_method_handler(
                    servicer.PreviewDeployment,
                    request_deserializer=prodvana_dot_deployment_dot_manager__pb2.PreviewDeploymentReq.FromString,
                    response_serializer=prodvana_dot_deployment_dot_manager__pb2.PreviewDeploymentResp.SerializeToString,
            ),
            'GetLatestDeployments': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLatestDeployments,
                    request_deserializer=prodvana_dot_deployment_dot_manager__pb2.GetLatestDeploymentsReq.FromString,
                    response_serializer=prodvana_dot_deployment_dot_manager__pb2.GetLatestDeploymentsResp.SerializeToString,
            ),
            'CheckCommitInDeployment': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckCommitInDeployment,
                    request_deserializer=prodvana_dot_deployment_dot_manager__pb2.CheckCommitInDeploymentReq.FromString,
                    response_serializer=prodvana_dot_deployment_dot_manager__pb2.CheckCommitInDeploymentResp.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'prodvana.deployment.DeploymentManager', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DeploymentManager(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def RecordDeployment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.deployment.DeploymentManager/RecordDeployment',
            prodvana_dot_deployment_dot_manager__pb2.RecordDeploymentReq.SerializeToString,
            prodvana_dot_deployment_dot_manager__pb2.RecordDeploymentResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDeploymentStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.deployment.DeploymentManager/UpdateDeploymentStatus',
            prodvana_dot_deployment_dot_manager__pb2.UpdateDeploymentStatusReq.SerializeToString,
            prodvana_dot_deployment_dot_manager__pb2.UpdateDeploymentStatusResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDeployments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.deployment.DeploymentManager/ListDeployments',
            prodvana_dot_deployment_dot_manager__pb2.ListDeploymentsReq.SerializeToString,
            prodvana_dot_deployment_dot_manager__pb2.ListDeploymentsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDeploymentsStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/prodvana.deployment.DeploymentManager/ListDeploymentsStream',
            prodvana_dot_deployment_dot_manager__pb2.ListDeploymentsReq.SerializeToString,
            prodvana_dot_deployment_dot_manager__pb2.ListDeploymentsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CompareDeployment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.deployment.DeploymentManager/CompareDeployment',
            prodvana_dot_deployment_dot_manager__pb2.CompareDeploymentReq.SerializeToString,
            prodvana_dot_deployment_dot_manager__pb2.CompareDeploymentResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PreviewDeployment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.deployment.DeploymentManager/PreviewDeployment',
            prodvana_dot_deployment_dot_manager__pb2.PreviewDeploymentReq.SerializeToString,
            prodvana_dot_deployment_dot_manager__pb2.PreviewDeploymentResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLatestDeployments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.deployment.DeploymentManager/GetLatestDeployments',
            prodvana_dot_deployment_dot_manager__pb2.GetLatestDeploymentsReq.SerializeToString,
            prodvana_dot_deployment_dot_manager__pb2.GetLatestDeploymentsResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CheckCommitInDeployment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.deployment.DeploymentManager/CheckCommitInDeployment',
            prodvana_dot_deployment_dot_manager__pb2.CheckCommitInDeploymentReq.SerializeToString,
            prodvana_dot_deployment_dot_manager__pb2.CheckCommitInDeploymentResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import prodvana.proto.prodvana.workflow.workflow_manager_pb2

class WorkflowManagerStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    ListIntegrations: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.ListIntegrationsReq,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.ListIntegrationsResp,
    ]
    DeleteIntegration: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.DeleteIntegrationReq,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.DeleteIntegrationResp,
    ]
    CreateContainerRegistryIntegration: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.CreateContainerRegistryIntegrationReq,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.CreateContainerRegistryIntegrationRes,
    ]
    DeleteContainerRegistryIntegration: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.DeleteContainerRegistryIntegrationReq,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.DeleteContainerRegistryIntegrationResp,
    ]
    ListContainerRegistryIntegrations: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.ListContainerRegistryIntegrationsReq,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.ListContainerRegistryIntegrationsResp,
    ]
    GetContainerRegistryIntegration: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetContainerRegistryIntegrationReq,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetContainerRegistryIntegrationResp,
    ]
    GetServiceImageInfo: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetServiceImageInfoReq,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetServiceImageInfoResp,
    ]
    GetContainerRegistryImages: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetContainerRegistryImagesReq,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetContainerRegistryImagesRes,
    ]
    ListTrackedImageRepositories: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.ListTrackedImageRepositoriesReq,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.ListTrackedImageRepositoriesResp,
    ]
    GetTrackedImageRepository: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetTrackedImageRepositoryReq,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetTrackedImageRepositoryResp,
    ]
    TrackImageRepositories: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.TrackImageRepositoriesReq,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.TrackImageRepositoriesResp,
    ]
    StopTrackingImageRepository: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.StopTrackingImageRepositoryReq,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.StopTrackingImageRepositoryResp,
    ]
    GetProgramDefaults: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetProgramDefaultsReq,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetProgramDefaultsResp,
    ]
    GetImageCommitInfo: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetImageCommitInfoReq,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetImageCommitInfoResp,
    ]
    InstallSlack: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.InstallSlackReq,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.InstallSlackResp,
    ]
    UninstallSlack: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.UninstallSlackReq,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.UninstallSlackResp,
    ]
    GetInstallSlackUrl: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetInstallSlackUrlReq,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetInstallSlackUrlResp,
    ]
    InstallPagerDuty: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.InstallPagerDutyReq,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.InstallPagerDutyResp,
    ]
    GetInstallPagerDutyUrl: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetInstallPagerDutyUrlReq,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetInstallPagerDutyUrlResp,
    ]
    UninstallPagerDuty: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.UninstallPagerDutyReq,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.UninstallPagerDutyResp,
    ]
    GetGrafanaInstallation: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetGrafanaInstallationReq,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetGrafanaInstallationResp,
    ]
    InstallGrafana: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.InstallGrafanaReq,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.InstallGrafanaResp,
    ]
    UninstallGrafana: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.UninstallGrafanaReq,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.UninstallGrafanaResp,
    ]
    ListHoneycombEnvironments: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.ListHoneycombEnvironmentsReq,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.ListHoneycombEnvironmentsResp,
    ]
    AddHoneycombEnvironment: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.AddHoneycombEnvironmentReq,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.AddHoneycombEnvironmentResp,
    ]
    UpdateHoneycombEnvironment: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.UpdateHoneycombEnvironmentReq,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.UpdateHoneycombEnvironmentResp,
    ]
    DeleteHoneycombEnvironment: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.DeleteHoneycombEnvironmentReq,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.DeleteHoneycombEnvironmentResp,
    ]
    UninstallHoneycomb: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.UninstallHoneycombReq,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.UninstallHoneycombResp,
    ]
    GetInstallGitHubUrl: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetInstallGitHubUrlReq,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetInstallGitHubUrlResp,
    ]
    CreateGitHubApp: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.CreateGitHubAppReq,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.CreateGitHubAppResp,
    ]
    InstallGitHub: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.InstallGitHubReq,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.InstallGitHubResp,
    ]
    ListRepoCommits: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.ListRepoCommitsReq,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.ListRepoCommitsResp,
    ]
    GetCommitInfo: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetCommitInfoReq,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetCommitInfoResp,
    ]
    InstallLast9: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.InstallLast9Req,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.InstallLast9Resp,
    ]
    UninstallLast9: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.UninstallLast9Req,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.UninstallLast9Resp,
    ]
    GetLast9Installation: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetLast9InstallationReq,
        prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetLast9InstallationResp,
    ]

class WorkflowManagerServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def ListIntegrations(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.ListIntegrationsReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.ListIntegrationsResp: ...
    @abc.abstractmethod
    def DeleteIntegration(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.DeleteIntegrationReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.DeleteIntegrationResp: ...
    @abc.abstractmethod
    def CreateContainerRegistryIntegration(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.CreateContainerRegistryIntegrationReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.CreateContainerRegistryIntegrationRes: ...
    @abc.abstractmethod
    def DeleteContainerRegistryIntegration(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.DeleteContainerRegistryIntegrationReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.DeleteContainerRegistryIntegrationResp: ...
    @abc.abstractmethod
    def ListContainerRegistryIntegrations(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.ListContainerRegistryIntegrationsReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.ListContainerRegistryIntegrationsResp: ...
    @abc.abstractmethod
    def GetContainerRegistryIntegration(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetContainerRegistryIntegrationReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetContainerRegistryIntegrationResp: ...
    @abc.abstractmethod
    def GetServiceImageInfo(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetServiceImageInfoReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetServiceImageInfoResp: ...
    @abc.abstractmethod
    def GetContainerRegistryImages(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetContainerRegistryImagesReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetContainerRegistryImagesRes: ...
    @abc.abstractmethod
    def ListTrackedImageRepositories(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.ListTrackedImageRepositoriesReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.ListTrackedImageRepositoriesResp: ...
    @abc.abstractmethod
    def GetTrackedImageRepository(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetTrackedImageRepositoryReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetTrackedImageRepositoryResp: ...
    @abc.abstractmethod
    def TrackImageRepositories(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.TrackImageRepositoriesReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.TrackImageRepositoriesResp: ...
    @abc.abstractmethod
    def StopTrackingImageRepository(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.StopTrackingImageRepositoryReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.StopTrackingImageRepositoryResp: ...
    @abc.abstractmethod
    def GetProgramDefaults(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetProgramDefaultsReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetProgramDefaultsResp: ...
    @abc.abstractmethod
    def GetImageCommitInfo(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetImageCommitInfoReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetImageCommitInfoResp: ...
    @abc.abstractmethod
    def InstallSlack(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.InstallSlackReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.InstallSlackResp: ...
    @abc.abstractmethod
    def UninstallSlack(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.UninstallSlackReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.UninstallSlackResp: ...
    @abc.abstractmethod
    def GetInstallSlackUrl(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetInstallSlackUrlReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetInstallSlackUrlResp: ...
    @abc.abstractmethod
    def InstallPagerDuty(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.InstallPagerDutyReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.InstallPagerDutyResp: ...
    @abc.abstractmethod
    def GetInstallPagerDutyUrl(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetInstallPagerDutyUrlReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetInstallPagerDutyUrlResp: ...
    @abc.abstractmethod
    def UninstallPagerDuty(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.UninstallPagerDutyReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.UninstallPagerDutyResp: ...
    @abc.abstractmethod
    def GetGrafanaInstallation(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetGrafanaInstallationReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetGrafanaInstallationResp: ...
    @abc.abstractmethod
    def InstallGrafana(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.InstallGrafanaReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.InstallGrafanaResp: ...
    @abc.abstractmethod
    def UninstallGrafana(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.UninstallGrafanaReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.UninstallGrafanaResp: ...
    @abc.abstractmethod
    def ListHoneycombEnvironments(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.ListHoneycombEnvironmentsReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.ListHoneycombEnvironmentsResp: ...
    @abc.abstractmethod
    def AddHoneycombEnvironment(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.AddHoneycombEnvironmentReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.AddHoneycombEnvironmentResp: ...
    @abc.abstractmethod
    def UpdateHoneycombEnvironment(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.UpdateHoneycombEnvironmentReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.UpdateHoneycombEnvironmentResp: ...
    @abc.abstractmethod
    def DeleteHoneycombEnvironment(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.DeleteHoneycombEnvironmentReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.DeleteHoneycombEnvironmentResp: ...
    @abc.abstractmethod
    def UninstallHoneycomb(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.UninstallHoneycombReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.UninstallHoneycombResp: ...
    @abc.abstractmethod
    def GetInstallGitHubUrl(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetInstallGitHubUrlReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetInstallGitHubUrlResp: ...
    @abc.abstractmethod
    def CreateGitHubApp(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.CreateGitHubAppReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.CreateGitHubAppResp: ...
    @abc.abstractmethod
    def InstallGitHub(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.InstallGitHubReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.InstallGitHubResp: ...
    @abc.abstractmethod
    def ListRepoCommits(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.ListRepoCommitsReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.ListRepoCommitsResp: ...
    @abc.abstractmethod
    def GetCommitInfo(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetCommitInfoReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetCommitInfoResp: ...
    @abc.abstractmethod
    def InstallLast9(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.InstallLast9Req,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.InstallLast9Resp: ...
    @abc.abstractmethod
    def UninstallLast9(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.UninstallLast9Req,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.UninstallLast9Resp: ...
    @abc.abstractmethod
    def GetLast9Installation(
        self,
        request: prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetLast9InstallationReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.workflow.workflow_manager_pb2.GetLast9InstallationResp: ...

def add_WorkflowManagerServicer_to_server(servicer: WorkflowManagerServicer, server: grpc.Server) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/common_config/parameters.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.common_config import program_pb2 as prodvana_dot_common__config_dot_program__pb2
from prodvana.proto.prodvana.common_config import env_pb2 as prodvana_dot_common__config_dot_env__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'prodvana/common_config/parameters.proto\x12\x16prodvana.common_config\x1a$prodvana/common_config/program.proto\x1a prodvana/common_config/env.proto\x1a\x17validate/validate.proto\"&\n\rProgramChange\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"2\n\x19StringParameterDefinition\x12\x15\n\rdefault_value\x18\x01 \x01(\t\"\xba\x02\n\x1e\x44ockerImageParameterDefinition\x12\x13\n\x0b\x64\x65\x66\x61ult_tag\x18\x01 \x01(\t\x12P\n\x13image_registry_info\x18\x02 \x01(\x0b\x32).prodvana.common_config.ImageRegistryInfoB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12^\n\x07\x63hanges\x18\x03 \x03(\x0b\x32>.prodvana.common_config.DockerImageParameterDefinition.ChangesB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x1aQ\n\x07\x43hanges\x12\x38\n\x07program\x18\x01 \x01(\x0b\x32%.prodvana.common_config.ProgramChangeH\x00\x42\x0c\n\x05oneof\x12\x03\xf8\x42\x01\"\x14\n\x12\x46ixedReplicaChange\"\xe5\x01\n\x16IntParameterDefinition\x12\x15\n\rdefault_value\x18\x01 \x01(\x03\x12V\n\x07\x63hanges\x18\x02 \x03(\x0b\x32\x36.prodvana.common_config.IntParameterDefinition.ChangesB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x1a\\\n\x07\x43hanges\x12\x43\n\rfixed_replica\x18\x01 \x01(\x0b\x32*.prodvana.common_config.FixedReplicaChangeH\x00\x42\x0c\n\x05oneof\x12\x03\xf8\x42\x01\"\x1b\n\x19SecretParameterDefinition\"H\n\x19\x43ommitParameterDefinition\x12\x1b\n\nrepository\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x0e\n\x06\x62ranch\x18\x02 \x01(\t\"0\n\x17\x42lobParameterDefinition\x12\x15\n\rdefault_value\x18\x01 \x01(\t\"\x87\x04\n\x13ParameterDefinition\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x43\n\x06string\x18\x03 \x01(\x0b\x32\x31.prodvana.common_config.StringParameterDefinitionH\x00\x12N\n\x0c\x64ocker_image\x18\x04 \x01(\x0b\x32\x36.prodvana.common_config.DockerImageParameterDefinitionH\x00\x12=\n\x03int\x18\x05 \x01(\x0b\x32..prodvana.common_config.IntParameterDefinitionH\x00\x12\x43\n\x06secret\x18\x06 \x01(\x0b\x32\x31.prodvana.common_config.SecretParameterDefinitionH\x00\x12\x43\n\x06\x63ommit\x18\x08 \x01(\x0b\x32\x31.prodvana.common_config.CommitParameterDefinitionH\x00\x12?\n\x04\x62lob\x18\t \x01(\x0b\x32/.prodvana.common_config.BlobParameterDefinitionH\x00\x12\x10\n\x08required\x18\x07 \x01(\x08\x42\x13\n\x0c\x63onfig_oneof\x12\x03\xf8\x42\x01\"w\n\x14SecretParameterValue\x12\x14\n\nraw_secret\x18\x01 \x01(\tH\x00\x12\x34\n\nsecret_ref\x18\x02 \x01(\x0b\x32\x1e.prodvana.common_config.SecretH\x00\x42\x13\n\x0csecret_oneof\x12\x03\xf8\x42\x01\":\n\x12\x42lobParameterValue\x12\x11\n\x07inlined\x18\x01 \x01(\tH\x00\x42\x11\n\nblob_oneof\x12\x03\xf8\x42\x01\"\xd6\x02\n\x0eParameterValue\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x10\n\x06string\x18\x02 \x01(\tH\x00\x12\r\n\x03int\x18\x04 \x01(\x03H\x00\x12V\n\x10\x64ocker_image_tag\x18\x05 \x01(\tB:\xfa\x42\x37r523^[A-Za-z0-9_][0-9A-Za-z_.-]*$|^sha256:[0-9a-f]{64}$H\x00\x12>\n\x06secret\x18\x06 \x01(\x0b\x32,.prodvana.common_config.SecretParameterValueH\x00\x12\x10\n\x06\x63ommit\x18\x07 \x01(\tH\x00\x12:\n\x04\x62lob\x18\x08 \x01(\x0b\x32*.prodvana.common_config.BlobParameterValueH\x00\x42\x12\n\x0bvalue_oneof\x12\x03\xf8\x42\x01J\x04\x08\x03\x10\x04R\x0c\x64ocker_image\"b\n\x10ParametersConfig\x12N\n\nparameters\x18\x01 \x03(\x0b\x32+.prodvana.common_config.ParameterDefinitionB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x42RZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_configb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.common_config.parameters_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_config'
  _PROGRAMCHANGE.fields_by_name['name']._options = None
  _PROGRAMCHANGE.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _DOCKERIMAGEPARAMETERDEFINITION_CHANGES.oneofs_by_name['oneof']._options = None
  _DOCKERIMAGEPARAMETERDEFINITION_CHANGES.oneofs_by_name['oneof']._serialized_options = b'\370B\001'
  _DOCKERIMAGEPARAMETERDEFINITION.fields_by_name['image_registry_info']._options = None
  _DOCKERIMAGEPARAMETERDEFINITION.fields_by_name['image_registry_info']._serialized_options = b'\372B\005\212\001\002\020\001'
  _DOCKERIMAGEPARAMETERDEFINITION.fields_by_name['changes']._options = None
  _DOCKERIMAGEPARAMETERDEFINITION.fields_by_name['changes']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _INTPARAMETERDEFINITION_CHANGES.oneofs_by_name['oneof']._options = None
  _INTPARAMETERDEFINITION_CHANGES.oneofs_by_name['oneof']._serialized_options = b'\370B\001'
  _INTPARAMETERDEFINITION.fields_by_name['changes']._options = None
  _INTPARAMETERDEFINITION.fields_by_name['changes']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _COMMITPARAMETERDEFINITION.fields_by_name['repository']._options = None
  _COMMITPARAMETERDEFINITION.fields_by_name['repository']._serialized_options = b'\372B\004r\002\020\001'
  _PARAMETERDEFINITION.oneofs_by_name['config_oneof']._options = None
  _PARAMETERDEFINITION.oneofs_by_name['config_oneof']._serialized_options = b'\370B\001'
  _PARAMETERDEFINITION.fields_by_name['name']._options = None
  _PARAMETERDEFINITION.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _SECRETPARAMETERVALUE.oneofs_by_name['secret_oneof']._options = None
  _SECRETPARAMETERVALUE.oneofs_by_name['secret_oneof']._serialized_options = b'\370B\001'
  _BLOBPARAMETERVALUE.oneofs_by_name['blob_oneof']._options = None
  _BLOBPARAMETERVALUE.oneofs_by_name['blob_oneof']._serialized_options = b'\370B\001'
  _PARAMETERVALUE.oneofs_by_name['value_oneof']._options = None
  _PARAMETERVALUE.oneofs_by_name['value_oneof']._serialized_options = b'\370B\001'
  _PARAMETERVALUE.fields_by_name['name']._options = None
  _PARAMETERVALUE.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _PARAMETERVALUE.fields_by_name['docker_image_tag']._options = None
  _PARAMETERVALUE.fields_by_name['docker_image_tag']._serialized_options = b'\372B7r523^[A-Za-z0-9_][0-9A-Za-z_.-]*$|^sha256:[0-9a-f]{64}$'
  _PARAMETERSCONFIG.fields_by_name['parameters']._options = None
  _PARAMETERSCONFIG.fields_by_name['parameters']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _globals['_PROGRAMCHANGE']._serialized_start=164
  _globals['_PROGRAMCHANGE']._serialized_end=202
  _globals['_STRINGPARAMETERDEFINITION']._serialized_start=204
  _globals['_STRINGPARAMETERDEFINITION']._serialized_end=254
  _globals['_DOCKERIMAGEPARAMETERDEFINITION']._serialized_start=257
  _globals['_DOCKERIMAGEPARAMETERDEFINITION']._serialized_end=571
  _globals['_DOCKERIMAGEPARAMETERDEFINITION_CHANGES']._serialized_start=490
  _globals['_DOCKERIMAGEPARAMETERDEFINITION_CHANGES']._serialized_end=571
  _globals['_FIXEDREPLICACHANGE']._serialized_start=573
  _globals['_FIXEDREPLICACHANGE']._serialized_end=593
  _globals['_INTPARAMETERDEFINITION']._serialized_start=596
  _globals['_INTPARAMETERDEFINITION']._serialized_end=825
  _globals['_INTPARAMETERDEFINITION_CHANGES']._serialized_start=733
  _globals['_INTPARAMETERDEFINITION_CHANGES']._serialized_end=825
  _globals['_SECRETPARAMETERDEFINITION']._serialized_start=827
  _globals['_SECRETPARAMETERDEFINITION']._serialized_end=854
  _globals['_COMMITPARAMETERDEFINITION']._serialized_start=856
  _globals['_COMMITPARAMETERDEFINITION']._serialized_end=928
  _globals['_BLOBPARAMETERDEFINITION']._serialized_start=930
  _globals['_BLOBPARAMETERDEFINITION']._serialized_end=978
  _globals['_PARAMETERDEFINITION']._serialized_start=981
  _globals['_PARAMETERDEFINITION']._serialized_end=1500
  _globals['_SECRETPARAMETERVALUE']._serialized_start=1502
  _globals['_SECRETPARAMETERVALUE']._serialized_end=1621
  _globals['_BLOBPARAMETERVALUE']._serialized_start=1623
  _globals['_BLOBPARAMETERVALUE']._serialized_end=1681
  _globals['_PARAMETERVALUE']._serialized_start=1684
  _globals['_PARAMETERVALUE']._serialized_end=2026
  _globals['_PARAMETERSCONFIG']._serialized_start=2028
  _globals['_PARAMETERSCONFIG']._serialized_end=2126
# @@protoc_insertion_point(module_scope)
